﻿Fluke                                                       MET/CAL Procedure
=============================================================================
INSTRUMENT:            LeCroy WaveAce 234: (1 year) VER DOS /9500+5Hd
DATE:                  2017-04-07 14:23:21
AUTHOR:                LeCroy Corporation
REVISION:              $Revision: 2624 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       215
CONFIGURATION:         Datron 9500 (C5)
CONFIGURATION:         Datron 9510 on channel 1
CONFIGURATION:         Datron 9510 on channel 2
CONFIGURATION:         Datron 9510 on channel 3
CONFIGURATION:         Datron 9510 on channel 4
CONFIGURATION:         Datron 9510 on channel 5
=============================================================================
#
#  Procedure Author:
#      FL, DAC, CAD
#
#  Source:
#      Lecroy WaveAce Performance Verification, Rev F
#
#  Compatibility:
#      MET/CAL 7.3 or later
#
#  Additional Equipment Required:
#      Type A male to type B male USB cable.
#
#  Due to OEM's policy of continuously updating products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, we cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  ASK-   R     N              P                   Z        F        V
  1.002  ASK+           K

# Dummy statements to force procedure header to include configuration
# required at run time.
  1.003  IF           0
  1.004  M9500                       CH1
  1.005  9500         300MH                        2Vpp           LS    S  L
  1.006  M9500                       CH2
  1.007  9500         300MH                        2Vpp           LS    S  L
  1.008  M9500                       CH3
  1.009  9500         300MH                        2Vpp           LS    S  L
  1.010  M9500                       CH4
  1.011  9500         300MH                        2Vpp           LS    S  L
  1.012  M9500                       CH5
  1.013  9500         300MH                        2Vpp           LS    S  L
  1.014  ENDIF

  1.015  IF           NOT(VERSIONCHECK("7.3"))
  1.016  DISP         This procedure requires Met/VERsion 7.3 or later.
  1.017  END
  1.018  ENDIF

  1.019  MATH         @Debug = 0

  1.020  HEAD         PRELIMINARY INSTRUCTIONS
  1.021  CALL         Sub Install LeCroy EasyScope
  1.022  CALL         Sub Display Copyright
  1.023  CALL         Sub High Voltage Safety Warning
  1.024  CALL         Sub Select Verification Method (No NTHROW)

  1.025  DISP         The calibration verification must be performed on
  1.025  DISP         an oscilloscope that has been warmed for at least
  1.025  DISP         15 minutes.  Turn ON and wait now if needed.

  1.026  DISP         Connect the PC to the UUT using Type A male to
  1.026  DISP         Type B male USB cable.

  1.027  MATH         @DataPath = "\"" & DFILE() & "\""

  1.028  HEAD         UUT IDENTIFICATION
  1.029  DOS          -x WaveAce.exe [V @DataPath] *RST

  1.030  MATH         @UUT_Manufacturer = "LECROY"
  1.031  MATH         @UUT_Model        = "WaveAce234"

  1.032  DO
  1.033  DOS          WaveAce.exe [V @DataPath] *IDN?
  1.034  MATH         HaveId = NOT(EMPTY(MEM2)) && FINDI(MEM2, "LeCroy", 0)

  1.035  IF           NOT(HaveId)
  1.036  OPBR         -z An error occurred while Identifying the
  1.036  OPBR         [V @UUT_Model].
  1.036  OPBR
  1.036  OPBR         Would you like to try again?

  1.037  IF           NOT(MEM1)
  1.038  HEAD         Procedure terminated!
  1.039  END
  1.040  ENDIF

  1.041  ENDIF

  1.042  UNTIL        HaveId

# Strip "*IDN " from the UUT's *IDN? response.  Example response:
# "*IDN LECROY,WaveAce<model number>,<serial number>,<firmware revision>"
  1.043  MATH         MEM2 = FLD(MEM2, 2, " ")
  1.044  CALL         Sub IEEE-488.2 Identification Query Parse Response
  1.045  CALL         Sub IEEE-488.2 Identification Query Check Response

  1.046  IF           @Abort
  1.047  END
  1.048  ENDIF

  1.049  IF           NOT(ZCMPI(@FirmwareRev, "1.01.01.13"))
  1.050  DISP         This DOS-based procedure only supports UUTs with
  1.050  DISP         firmware version 1.01.01.13.
  1.050  DISP
  1.050  DISP         All other firmware verions must use the VISA version of
  1.050  DISP         this same procedure.
  1.051  ENDIF

# Set: Number of channels; Bandwidth.
  1.052  MATH         @NumChan = 4; @Bandwidth = 300E+6

  1.053  CALL         Sub LeCroy WaveAce Self Calibration

  1.054  HEAD         INSTRUMENT CONNECTIONS
  1.055  DISP         Make the following connections:
  1.055  DISP
  1.055  DISP         [32]       9500          to     UUT
  1.055  DISP         [32]  CH 1 ACTIVE HEAD -------> CH1
  1.055  DISP         [32]  CH 2 ACTIVE HEAD -------> CH2
  1.055  DISP         [32]  CH 3 ACTIVE HEAD -------> CH3
  1.055  DISP         [32]  CH 4 ACTIVE HEAD -------> CH4
  1.055  DISP         [32]  CH 5 ACTIVE HEAD -------> EXT TRIG

  1.056  MATH         @Chan = 1
  1.057  M9500                       CH1
  1.058  CALL         Sub LeCroy WaveAce (1 yr) Ch Input Imped VER DOS /9500

  1.059  MATH         @Chan = 2
  1.060  M9500                       CH2
  1.061  CALL         Sub LeCroy WaveAce (1 yr) Ch Input Imped VER DOS /9500

  1.062  MATH         @Chan = 3
  1.063  M9500                       CH3
  1.064  CALL         Sub LeCroy WaveAce (1 yr) Ch Input Imped VER DOS /9500

  1.065  MATH         @Chan = 4
  1.066  M9500                       CH4
  1.067  CALL         Sub LeCroy WaveAce (1 yr) Ch Input Imped VER DOS /9500

  1.068  M9500                       CH5
  1.069  CALL         Sub LeCroy WaveAce (1 yr) Ext Input Imped VER DOS /9500

  1.070  MATH         @Chan = 1
  1.071  M9500                       CH1
  1.072  CALL         Sub LeCroy WaveAce (1 yr) DC Gain Acc VER DOS /9500

  1.073  MATH         @Chan = 2
  1.074  M9500                       CH2
  1.075  CALL         Sub LeCroy WaveAce (1 yr) DC Gain Acc VER DOS /9500

  1.076  MATH         @Chan = 3
  1.077  M9500                       CH3
  1.078  CALL         Sub LeCroy WaveAce (1 yr) DC Gain Acc VER DOS /9500

  1.079  MATH         @Chan = 4
  1.080  M9500                       CH4
  1.081  CALL         Sub LeCroy WaveAce (1 yr) DC Gain Acc VER DOS /9500

  1.082  MATH         @Chan = 1
  1.083  M9500                       CH1
  1.084  CALL         Sub LeCroy WaveAce (1 yr) Bandwidth VER DOS /9500

  1.085  MATH         @Chan = 2
  1.086  M9500                       CH2
  1.087  CALL         Sub LeCroy WaveAce (1 yr) Bandwidth VER DOS /9500

  1.088  MATH         @Chan = 3
  1.089  M9500                       CH3
  1.090  CALL         Sub LeCroy WaveAce (1 yr) Bandwidth VER DOS /9500

  1.091  MATH         @Chan = 4
  1.092  M9500                       CH4
  1.093  CALL         Sub LeCroy WaveAce (1 yr) Bandwidth VER DOS /9500

  1.094  MATH         @Chan = 1
  1.095  M9500                       CH1
  1.096  CALL         Sub LeCroy WaveAce (1 yr) Horizontal Acc VER DOS /9500

  1.097  MATH         @Chan = 1
  1.098  M9500                       CH1
  1.099  CALL         Sub LeCroy WaveAce (1 yr) Int Trig Sens VER DOS /9500

  1.100  MATH         @Chan = 2
  1.101  M9500                       CH2
  1.102  CALL         Sub LeCroy WaveAce (1 yr) Int Trig Sens VER DOS /9500

  1.103  MATH         @Chan = 3
  1.104  M9500                       CH3
  1.105  CALL         Sub LeCroy WaveAce (1 yr) Int Trig Sens VER DOS /9500

  1.106  MATH         @Chan = 4
  1.107  M9500                       CH4
  1.108  CALL         Sub LeCroy WaveAce (1 yr) Int Trig Sens VER DOS /9500

  1.109  MATH         @Chan = 1
  1.110  M9500                       CH1                                   1T5
  1.111  CALL         Sub LeCroy WaveAce (1 yr) Ext Trig Sens VER DOS /9500

  1.112  RSLT         =
  1.113  HEAD         {V E R I F I C A T I O N   C O M P L E T E}
  1.114  END
