﻿Fluke Corporation                                           MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub LeCroy WaveAce Self Calibration
INSTRUMENT:            Sub LeCroy WaveAce Select Channel & Trig Src DOS
INSTRUMENT:            Sub LeCroy WaveAce Send Command DOS
INSTRUMENT:            Sub LeCroy WaveAce Parameter Value Query DOS
DATE:                  2011-01-31 09:52:27
AUTHOR:                Fluke Calibration
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       6
NUMBER OF LINES:       257
=============================================================================
#
#  Procedure Author:
#      FL, DAC, CAD
#
#  Model(s) Covered:
#      WaveAce 101, 102, 112, 202, 204, 212, 214, 222, 224, 232, 234
#
#  Source:
#      Lecroy WaveAce Performance Verification, Rev F
#
#  Compatibility:
#      MET/CAL 7.3 or later
#
#  Subprocedures:
#      None
#
#  Required Files
#      WaveAce.exe
#
#  Additional Equipment Required:
#      None
#
#  Due to OEM's policy of continuously updating products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, we cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  JMPL         SELF_CAL                    PSUBI("Self Calibration")
  1.002  JMPL         SELECT_CHANNEL              PSUBI("Select Channel")
  1.003  JMPL         SEND_COMMAND                PSUBI("Send Command")
  1.004  JMPL         PARAMETER_VALUE             PSUBI("Parameter Value")
  1.005  DISP         {Undefined subprocedure!}
  1.006  END

  1.007  EVAL   Increment step number

# Sub LeCroy WaveAce Self Calibration ========================================

  2.001  LABEL        SELF_CAL

#  2.002  DOS          -x WaveAce.exe [V @DataPath] *RST

# *CAL? always returns "executing" or starts another self-calibration.
#  1.052  DOS          -x WaveAce.exe [V @DataPath] *CAL?

  2.002  RSLT         =
  2.003  HEAD         SELF CALIBRATION
  2.004  TARGET       -p
  2.005  DISP         Ensure nothing is connected to the UUT input
  2.005  DISP         channels at this time.

  2.006  DISP         On the UUT front panel:
  2.006  DISP
  2.006  DISP         Press FORCE.
  2.006  DISP
  2.006  DISP         Press UTILITY.
  2.006  DISP
  2.006  DISP         Press "Do Self Cal" softkey.
  2.006  DISP
  2.006  DISP         Follow the UUT on-screen instructions to perform
  2.006  DISP         Self Cal.
  2.006  DISP
  2.006  DISP         Select "Advance" when Self Cal completes.
  2.007  EVAL   -s "SELF CALIBRATION" : Did the Self Cal Pass?

  3.001  END

  3.002  EVAL   Increment step number


# Sub LeCroy WaveAce Select Channel & Trig Src DOS ===========================

# This sub must be called direcly after a *RST.

  4.001  LABEL        SELECT_CHANNEL

# Prevent UUT from entering screen saver mode to prevent intermittent
# communication errors.
  4.002  MATH         @CmdFunc = "SCSV"; @CmdType = "NO"
  4.003  CALL         Sub LeCroy WaveAce Send Command DOS

  4.004  IF           @Chan != 1

  4.005  MATH         @CmdFunc = "C" & @Chan & ":TRACE"; @CmdType = "ON"
  4.006  CALL         Sub LeCroy WaveAce Send Command DOS

  4.007  MATH         @CmdFunc = "C1:TRACE"; @CmdType = "OFF"
  4.008  CALL         Sub LeCroy WaveAce Send Command DOS

  4.009  MATH         @CmdFunc = "TRSE"; @CmdType = "EDGE,SR,C" & @Chan
  4.010  CALL         Sub LeCroy WaveAce Send Command DOS

  4.011  ENDIF

  4.012  END

  4.013  EVAL   Increment step number


# Sub LeCroy WaveAce Send Command DOS ========================================

  5.001  LABEL        SEND_COMMAND

# Initialize retry counter and retry limit.
  5.002  MATH         RetryCount = 0; RetryLimit = 20

# Assemble the command string.
  5.003  MATH         Command = @CmdFunc & " " & @CmdType

  5.004  DO

# Send Command.
  5.005  DOS          -x WaveAce.exe [V @DataPath] [V Command]

# Clear MEM2 before query to ensure we don't get an old response echo.
  5.006  MATH         MEM2 = ""

# Query for UUT acceptance of the command.
  5.007  DOS          -x WaveAce.exe [V @DataPath] [V @CmdFunc]?

# Check for valid response(s).
  5.008  MATH         CmdOK = FINDI(MEM2, @CmdType, 0)

  5.009  IF           ISVAR("@CmdType2")
  5.010  MATH         CmdOK = CmdOK + FINDI(MEM2, @CmdType2, 0)
  5.011  MATH         DEL(@CmdType2)
  5.012  ENDIF

  5.013  IF           NOT(CmdOK) && (RetryCount < RetryLimit)

  5.014  HEAD         -2 UUT is processing command: [V Command]
  5.015  MATH         RetryCount = RetryCount + 1

  5.016  IF           @Debug
  5.017  RSLT         =DEBUG:([V RetryCount]) Cmd: [V Command]; Query: [MEM2]
  5.018  ENDIF        ; Debug

  5.019  ELSEIF       (RetryCount >= RetryLimit)

  5.020  DISP         {An error occurred processing the command:}
  5.020  DISP
  5.020  DISP         {[V Command]}
  5.020  DISP
  5.020  DISP         [V RetryCount] attempts to retry have failed.
  5.020  DISP
  5.020  DISP         This typically only occurs when the UUT screen saver
  5.020  DISP         engages while processing a remote command.  Please
  5.020  DISP         terminate this procedure, cycle the UUT power, and
  5.020  DISP         re-start this procedure.

# Restore HEAD -2 if it exists, otherwise clear the error message.
  5.021  IF           ISVAR("@Head2")
  5.022  HEAD         -2 [V @Head2]
  5.023  ELSE
  5.024  HEAD         -2
  5.025  ENDIF

  5.026  MATH         @Abort = 1
  5.027  END

  5.028  ENDIF

  5.029  UNTIL        CmdOK

# Restore HEAD -2 if it exists, otherwise clear the error message.
  5.030  IF           ISVAR("@Head2")
  5.031  HEAD         -2 [V @Head2]
  5.032  ELSE
  5.033  HEAD         -2
  5.034  ENDIF

  5.035  END

  5.036  EVAL   Increment Step Number


# Sub LeCroy WaveAce Parameter Value Query DOS ===============================

  6.001  LABEL        PARAMETER_VALUE

# Initialize retry counter and retry limit.
  6.002  MATH         RetryCount = 0; RetryLimit = 10

  6.003  DO

# Clear MEM2 before query to ensure we don't get an old response echo.
  6.004  MATH         MEM2 = ""
  6.005  DOS          -x WaveAce.exe [V @DataPath] PAVA? CUST1
  6.006  MATH         Result = FLD(MEM2, 2, ",")

  6.007  MATH         L[1] = NOT(FINDI(MEM2, "PArameter_VAlue", 0))
  6.008  MATH         L[2] = NOT(IS_NUM_SUB(Result))
  6.009  MATH         ReadoutProblem = SUM_L(1, 2)

  6.010  IF           ReadoutProblem && (RetryCount < RetryLimit)

  6.011  HEAD         -2 Retreiving UUT Measurement Function value...

  6.012  MATH         RetryCount = RetryCount + 1

  6.013  IF           @Debug
  6.014  RSLT         =DEBUG:([V RetryCount]) PAVA? response: [MEM2]
  6.015  ENDIF        ; Debug

  6.016  ELSEIF       RetryCount >= RetryLimit

  6.017  DISP         {An error occurred while reading the UUT}
  6.017  DISP         {Measurement Function readout.}
  6.017  DISP
  6.017  DISP         This could not be resolved after
  6.017  DISP         [V RetryCount] attempts.

# Restore HEAD -2 if it exists, otherwise clear the error message.
  6.018  IF           ISVAR("@Head2")
  6.019  HEAD         -2 [V @Head2]
  6.020  ELSE
  6.021  HEAD         -2
  6.022  ENDIF

  6.023  END

  6.024  ELSE         ; Store valid reading.

  6.025  MATH         MEM = BASE(Result)

  6.026  ENDIF

  6.027  UNTIL        NOT(ReadoutProblem)

  6.028  IF           ISVAR("@Head2")
  6.029  HEAD         -2 [V @Head2]
  6.030  ELSE
  6.031  HEAD         -2
  6.032  ENDIF

  6.033  END
